@@ -456,10 +456,19 @@ def server_main(args=None):
                            help='Uninstall the service.')
         options.add_option('--start', action='store_true', help='Start the service.')
         options.add_option('--stop', action='store_true', help='Stop the service, but don\'t uninstall it.')
+        options.add_option('--query-installed', action='store_true', 
+                           help='Exits with code 0 if the service is installed, '
+                           'or code 1 if it is not.')
 
     opts, args = options.parse_args(args)
 
     if servmod:
+        if opts.query_installed:
+            if servmod.query_service_installed():
+                return 0
+            else:
+                return 1
+
         if opts.install:
             key = _core.key_from_options(opts, False)
             if key:
